savedcmd_arch/arm64/boot/dts/freescale/imx8mm-venice-gw73xx-0x-rs422.dtb := ./scripts/dtc/fdtoverlay -o arch/arm64/boot/dts/freescale/imx8mm-venice-gw73xx-0x-rs422.dtb -i arch/arm64/boot/dts/freescale/imx8mm-venice-gw73xx-0x.dtb arch/arm64/boot/dts/freescale/imx8mm-venice-gw73xx-0x-rs422.dtbo
