savedcmd_arch/arm64/boot/dts/freescale/imx8mp-venice-gw74xx-rpidsi.dtb := ./scripts/dtc/fdtoverlay -o arch/arm64/boot/dts/freescale/imx8mp-venice-gw74xx-rpidsi.dtb -i arch/arm64/boot/dts/freescale/imx8mp-venice-gw74xx.dtb arch/arm64/boot/dts/freescale/imx8mp-venice-gw74xx-rpidsi.dtbo
